@@ -24,7 +24,6 @@
 
 #include "config.h"
 #include <glade/glade.h>
-#include <stdio.h>
 #include <sys/stat.h>
 #include <unistd.h>
 #include <gcu/element.h>
@@ -33,9 +32,11 @@
 #include "document.h"
 #include "view.h"
 #include "globals.h"
+#include <gtk/gtkglinit.h>
 #include <libgnomevfs/gnome-vfs-init.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <glib/gi18n.h>
+#include <cstdio>
 
 using namespace gcu;
 using namespace std;
@@ -48,28 +49,6 @@ GtkWidget *mainwindow, *vbox1 ;
 GConfClient *conf_client;
 guint NotificationId;
 
-/* Following code is removed because libgnomeui is going to be deprecated
-* Just I don't know what will replace GnomeClient *
-static void session_die(GnomeClient *client, gpointer data)
-{
-   gtk_main_quit();
-}
-
-static gint session_save(GnomeClient *client, gint phase, GnomeSaveStyle save_style, gint is_shutdown, GnomeInteractStyle interact_style, gint is_fast, gpointer client_data)
-{
-	gchar **argv;
-	gint argc;
-	if (IsEmbedded())
-	{
-		argv = (gchar**) g_malloc0(sizeof(gchar*) * 3);
-		argc = 2;
-		argv[0] = (gchar*) client_data;
-		argv[1] = "--bonobo-server";
-		gnome_client_set_clone_command(client, argc, argv);
-		gnome_client_set_restart_command(client, argc, argv);
-	}
-}*/
-
 static void on_config_changed (GConfClient *client,  guint cnxn_id, GConfEntry *entry, gpointer user_data)
 {
 	g_return_if_fail (client == conf_client);
@@ -118,9 +97,9 @@ int main(int argc, char *argv[])
 	textdomain(GETTEXT_PACKAGE);
 
 	gtk_init (&argc, &argv);
+	gtk_gl_init (&argc, &argv);
 	gnome_vfs_init ();
 	Element::LoadRadii ();
-//	gnome_authentication_manager_init ();
 	if (argc > 1 && argv[1][0] == '-') {
 		context = g_option_context_new (_(" [file...]"));
 		g_option_context_add_main_entries (context, entries, GETTEXT_PACKAGE);
